#
# spec file for package colord-gtk
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           colord-gtk
Version:        0.3.0
Release:        2.1
Summary:        System Daemon for Managing Color Devices -- GTK Integration
License:        LGPL-2.1-or-later
Group:          System/Daemons
URL:            https://www.freedesktop.org/software/colord
Source0:        https://www.freedesktop.org/software/colord/releases/colord-gtk-%{version}.tar.xz
Source1:        https://www.freedesktop.org/software/colord/releases/colord-gtk-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM Fix-the-callback-signature-to-fix-a-crash.patch bsc#1212840 gh#hughsie/colord-gtk#22 -- Fix segfault when turning monitor back on
Patch1:         Fix-the-callback-signature-to-fix-a-crash.patch
BuildRequires:  docbook5-xsl-stylesheets
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(colord) >= 0.1.27
BuildRequires:  pkgconfig(gio-2.0) >= 2.25.9
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.28.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(lcms2) >= 2.2

%description
colord is a system activated daemon that maps devices to color profiles.
It is used by gnome-color-manager for system integration and use when
there are no users logged in.

%package -n libcolord-gtk1
Summary:        System Daemon for Managing Color Devices -- GTK Integration Library
Group:          System/Libraries
Suggests:       colord
# for the -lang package to be installable
Provides:       %{name} = %{version}

%description -n libcolord-gtk1
colord is a system activated daemon that maps devices to color profiles.
It is used by gnome-color-manager for system integration and use when
there are no users logged in.

%package -n libcolord-gtk4-1
Summary:        System Daemon for Managing Color Devices -- GTK Integration Library
Group:          System/Libraries
Suggests:       colord
# for the -lang package to be installable
#Provides:       %%{name} = %%{version}

%description -n libcolord-gtk4-1
colord is a system activated daemon that maps devices to color profiles.
It is used by gnome-color-manager for system integration and use when
there are no users logged in.

%package -n typelib-1_0-ColordGtk-1_0
Summary:        GTK Integration Introspection bindings for colord-gtk
Group:          System/Libraries

%description -n typelib-1_0-ColordGtk-1_0
colord is a system activated daemon that maps devices to color profiles.
It is used by gnome-color-manager for system integration and use when
there are no users logged in.

This package provides the GObject Introspection bindings for the
libcolord-gtk library.

%package -n libcolord-gtk-devel
Summary:        System Daemon for Managing Color Devices -- GTK Integration Development Files
Group:          Development/Languages/C and C++
Requires:       libcolord-gtk1 = %{version}
Requires:       libcolord-gtk4-1 = %{version}
Requires:       typelib-1_0-ColordGtk-1_0 = %{version}

%description -n libcolord-gtk-devel
colord is a system activated daemon that maps devices to color profiles.
It is used by gnome-color-manager for system integration and use when
there are no users logged in.

%package doc
Summary:        Development Documentation for colord-gtk
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package contains development documentation for the colord-gtk packages.


%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dvapi=true \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%ldconfig_scriptlets -n libcolord-gtk1
%ldconfig_scriptlets -n libcolord-gtk4-1

%files lang -f %{name}.lang

%files
%{_bindir}/cd-convert
%{_mandir}/man1/cd-convert.1%{ext_man}

%files -n libcolord-gtk1
%license COPYING
%{_libdir}/libcolord-gtk.so.*

%files -n libcolord-gtk4-1
%{_libdir}/libcolord-gtk4.so.*

%files -n typelib-1_0-ColordGtk-1_0
%{_libdir}/girepository-1.0/ColordGtk-1.0.typelib

%files -n libcolord-gtk-devel
%{_includedir}/colord-1/colord-gtk.h
%{_includedir}/colord-1/colord-gtk/
%{_libdir}/libcolord-gtk.so
%{_libdir}/pkgconfig/colord-gtk.pc
%{_datadir}/gir-1.0/ColordGtk-1.0.gir
%{_datadir}/vala/vapi/colord-gtk.vapi
%{_datadir}/vala/vapi/colord-gtk.deps
%{_libdir}/libcolord-gtk4.so
%{_libdir}/pkgconfig/colord-gtk4.pc

%files doc
%doc AUTHORS NEWS README
%{_datadir}/gtk-doc/html/%{name}

%changelog
* Thu Jun 29 2023 Michal Kubecek <mkubecek@suse.cz>
- fix segfault when turning monitor back on (bsc#1212840):
  Fix-the-callback-signature-to-fix-a-crash.patch
* Mon May  2 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to stable release 0.3.0
  + Stable release
  + Sync spec file with downstream
- Use source signature
* Tue Mar 22 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build libcolord-gtk4-1-32bit: there is no consumer and so
  far we avoid putting gtk4-32bit up.
* Tue Feb 15 2022 bjorn.lie@gmail.com
- Update to version 0.2.0+8:
  * trivial: Fix link to homepage
  * trivial: Use the right vala package
  * build: Make GTK3 build optional too
  * Add a GTK4 variant
  * build: Rename 'gtk' meson variable to 'gtk3'
  * Make introspection optional in meson
  * Update the example spec file
  * trivial: post release version bump
- Switch to git checkout.
- Add pkgconfig(gtk4) BuildRequires: Build the new gtk4 support.
* Fri Oct 22 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.0:
  + New Features:
  - Migrate to gettext
  - Port to DocBook 5
  - Port to the Meson build system
  + Bugfixes:
  - Do not leak plug_name
  - Fix gtk-doc build when srcdir != builddir
- Add meson BuildRequires and macros following upstreams port to
  meson buildsystem.
- Add gtk-doc and docbook5-xsl-stylesheets BuildRequires, build
  gtk-doc development documentation and manpages. Following this
  split out new -doc sub-package.
- Drop intltool, no longer needed.
- Package COPYING as license, as this was somehow missed in the
  past.
- Modernize spec/cleanup.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Apr 14 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Dec 16 2014 dimstar@opensuse.org
- Update to version 0.1.26:
  + New Features:
  - Actually install the cd-convert utility.
  - Provide an optional Gtk2 version of libcolord-gtk.
  + Bugfixes:
  - Do not link against the unused gio-unix-2.0.
  - Fix cd-convert to work with multiple sensors attached.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 0.1.25:
  + New Feature: Give the sample widget slightly curved corners and
    a gray outline.
  + Bugfixes:
  - Do not use deprecated functions from libcolord.
  - Fix warnings when building ColordGtk-1.0.gir.
  - Fix up the licence boilerplate for CdSampleWidget.
* Wed Dec 19 2012 dimstar@opensuse.org
- Update to version 0.1.24:
  + New Feature: Hide the mouse cursor when it goes over the sample
    widget.
  + Bugfixes:
  - Don't use a GtkImage for the sample window.
  - Fix automatic dep on vala.
  - Fix the build.
  - Never use -Werror as it breaks jhbuild.
- Pass --enable-vala to configure to ensure the vala bindings are
  built.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 0.1.23:
  + Bugfixes:
  - Do not reuse __COLORD_H_INSIDE__ as this causes #include
    insanity
  - Add include guards to cd-sample-window.h
- Changes from version 0.1.23:
  + New Features:
  - Import GTK-specific code from colord into a new project
  + Bugfixes:
  - Assorted colord-gtk introspection fixes
  - Clarify that CdSampleWindow is LGPLv2+, not GPLv2+
  - Fix release instructions and version number
  - Fix Vala binding generation for colord-gtk
- NEW Package: colord-gtk used to be an integrated part of colord,
  which we split in an own spec file due to build loops. Upstream
  now followed this split. As a result, the .spec file has been
  entirely remastered and stripped.
* Thu Jul  5 2012 meissner@suse.com
- Add a apparmor profile for usr.lib.colord
* Wed May 23 2012 zaitor@opensuse.org
- Update to version 0.1.21:
  + Do not add sensors that are ignored or have no caps.
  + Do not install any parts of colord-sane if --disable-sane is
    specified.
  + Do not use 'WantedBy=graphical.target' in the shipped systemd
    file.
  + Fix autotools when configuring without systemd.
  + Fix InstallSystemWide() by not writing a private file.
  + Fix srcdir != builddir with introspection enabled.
  + Fix the description in the systemd service file.
  + Isolate gtk dependency to cd-convert.
  + Save the CCMX and ITx files to be compatible with argyllcms
  + The ColorHug has a new VID and PID.
- Drop colord-build-no-gtk.patch, fixed upstream.
- Removed call to gnome-autogen.sh and drop gnome-common
  buildrequires, only needed for above dropped patch.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 0.1.20:
  + New Features:
  - Add a bash completion file for colormgr
  - Add a BUSY state value for sensor devices
  - Add a GObject Introspection example
  - Add a sensor-set-options command to the colormgr tool
  - Add async and sync methods in libcolord to support sensor
    options
  - Add CdIt8 as a helper for reading and writing ti1, ti3 and
    ccmx files
  - Add cd_it8_utils_calculate_ccmx() to libcolorhug
  - Add CdSampleWindow to libcolord-gtk
  - Add CdWindow which allows us to get the color profile for a
    GtkWidget
  - Add functionality to colord-convert to sample ti1 -> ti3
    files
  - Add gio-2.0 to the requires line of colord.pc for GFile
  - Add the concept of 'options' on each color sensor device
  - colorhug: Allow saving the remote hash as a sensor option
  - Print any sensor options when doing 'colormgr get-sensors'
  + Bugfixes:
  - colorhug: Save the EEPROM after setting sensor options
  - Enable gtk-doc in the default distro build
  - Fix build failure when colord is not installed system-wide
- Add colord-build-no-gtk.patch: fix build without GTK+.
- Add gnome-common BuildRequires and call to gnome-autogen.sh,
  needed for above patch.
- Enable the build of colord-gtk, by creating a colord-gtk.spec
  based on colord.spec (with pre_checkin.sh). We do it this way to
  avoid a build loop between colord and gtk3, since gtk3 depends on
  colord. The differences are:
  + Add a pkgconfig(gtk+-3.0) BuildRequires.
  + Add colord and libcolord-devel BuildRequires, so we can use rpm
    to remove the files from colord.spec subpackages in %%install
    (in order to only package colord-gtk files).
  + Create libcolord-gtk1, typelib-1_0-ColordGtk-1_0 and
    libcolord-gtk-devel subpackages.
* Wed Apr 18 2012 vuntz@opensuse.org
- Update to version 0.1.19:
  + New Features:
  - Add a user suffix to the object path of user-created devices
    and profiles
  + Bugfixes:
  - Add User key to colord-sane's DBus service file
  - Do not enable PrivateNetwork=yes as it breaks hotplugging
    devices
  - Ensure colord-sane can create devices and profiles
  - Fix usage of CD_OBJECT_SCOPE_* enums
  - Honor aclocal flags
  - Remove the 'Default,' profile title prefix if legacy profiles
    are installed
* Thu Mar 15 2012 vuntz@opensuse.org
- Update to version 0.1.18:
  + New Features:
  - Add a Manager.CreateProfileWithFd() method for QtDBus
  - Add the GAMUT_coverage metadata key to the spec
  - Add the GAMUT_volume metadata key to the spec
  - Depend on lcms2 >= 2.2
  - Make cd-fix-profile add the GAMUT keys to the ICC file
  - Split out the SANE support into it's own process
  + Bugfixes:
  - Do not delete 'disk' or 'normal' devices when the session
    exits
  - Ensure we return NULL for missing device properties
  - Fix a small leak when creating devices and profiles in
    clients
  - Fix cd-fix-profile to add and remove metadata entries
  - Install per-machine profiles in /var/lib/colord/icc
  - Show what DBus names have inhibited each device
  - When doing 'get-devices' show the profile ID and filename
- Add new colord-sane.service as argument to calls to
  %%service_{add,del}_* macros.
* Mon Feb 27 2012 vuntz@opensuse.org
- Fix systemd-related packaging:
  + Use %%{?systemd_requires}.
  + Call %%service_{add,del}_* macros in scriptlets for
    colord.service.
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 0.1.17:
  + New Features:
  - Add an LED sample type
  - Add a metadata key to store the calibration brightness
  - Show the profile title when using colormgr get-profiles
  + Bugfixes:
  - Add PrivateNetwork and PrivateTmp to the systemd service file
  - Don't leak a GVariantIter when setting the device metadata
  - Fix a critical warning if a client tries to get the profile
    metadata
  - Fix InstallSystemWide() when running as the colord user
  - Increase the colorhug sample timeout to 5 seconds
  - Make underscores into spaces for the profile title
  - Return from cd_profile_has_access() with TRUE for virtual
    profiles
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Wed Jan 18 2012 vuntz@opensuse.org
- Add pkgconfig(gusb) BuildRequires to build with libgusb support,
  which matters even more now than libusb support is gone.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 0.1.16:
  + New Features:
  - Add a device-inhibit command to the colormgr client
  - Add org.freedesktop.policykit.owner annotations to .policy
    file
  - Add profile metadata MAPPING_device_id for automatic profile
    mapping
  - Add some profile metadata keys
  - Install a systemd service file if systemd is used
  - Support 2nd generation Huey hardware
  - Use GUsb for the Huey sensor
  + Bugfixes:
  - Fix a Wformat error when printing a gsize
  - If /usr/share/color appears at runtime, don't rescan the
    parent dir
  - Set the colorimeter sensor group so the dameon can access the
    sensor
  - Split the spyder hardware into different types
- Add pkgconfig(systemd) BuildRequires, following upstream change,
  to know where to install the .service file.
- Remove pkgconfig(libusb-1.0) BuildRequires: the dependency is
  gone now.
- Drop colord-polkit-annotate-owner.patch: fixed upstream.
- Remove libtool BuildRequires and call to autoreconf and
  intltoolize, that were only needed for above patch.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Colord-1_0 subpackage.
- Add typelib-1_0-Colord-1_0 Requires to libcolord-devel
  subpackage.
* Tue Dec  6 2011 vuntz@opensuse.org
- Run the colord daemon as user colord (bnc#698250):
  + Add colord-polkit-annotate-owner.patch: add
    org.freedesktop.policykit.owner annotations to policy file so
    that running as colord user works.
  + Add a %%pre script to create the colord user and change
    ownership of /var/lib/colord.
  + Add pwdutils Requires(pre), to make sure we can create the
    user.
  + Pass --with-daemon-user=colord to configure.
  + Package /var/lib/colord with the right user.
  + Add libtool BuildRequires and calls to autoreconf and
    intltoolize, as needed by above patch.
* Tue Nov 29 2011 dimstar@opensuse.org
- Update to version 0.1.15:
  + This release fixes an important security bug: CVE-2011-4349.
  + New Features:
  - Add a native driver for the Hughski ColorHug hardware
  - Export cd-math as three projects are now using it
  + Bugfixes:
  - Documentation fixes and improvements
  - Do not crash the daemon if adding the device to the db failed
  - Do not match any sensor device with a kernel driver
  - Don't be obscure when the user passes a device-id to colormgr
  - Fix a memory leak when getting properties from a device
  - Fix colormgr device-get-default-profile
  - Fix some conection bugs in colormgr
  - Fix some potential SQL injections
  - Make gusb optional
  - Only use the udev USB helper if the PID and VID have matches
  - Output the Huey calibration matrices when dumping the sensor
* Wed Nov 16 2011 dimstar@opensuse.org
- Update to version 0.1.14:
  + New Features:
  - Add defines for the i1 Display 3
  - Add two more DATA_source values to the specification
  - Align the output from colormgr get-devices and get-profiles
  - Allow cd-fix-profile to append and edit new metadata
  + Bugfixes:
  - Ensure non-native device are added with no driver module
  - Split the sensor and device udev code
  + Updated translations.
* Fri Oct 28 2011 lnussel@suse.de
- don't recommend colord from libcolord1 to prevent automatic
  installation (bnc#698250)
* Mon Oct  3 2011 dimstar@opensuse.org
- Update to version 0.1.13:
  + New Features:
  - Add an 'Owner' property on device and profile objects
  - Add cd_profile_has_access() to filter profiles from other
    user accounts
  - Add the crayon named color palette
  - Add --xorg-gamma to cd-create-profile to create custom gamma
    ramps
  + Bugfixes:
  - Add a note in the naming specification about the username
    suffix
  - colormgr only needs one argument for find-device
  - Ensure remote DBus errors are registered at startup
  - Ensure uid 0 can always create devices and profiles
  - Fix an error in configure if there is no sane .pc file
  - Fix the --disable-polkit build
  - Documentation: cd_device_get_modified() returns microseconds
  - Reduce the CPU load of clients when assigning profiles from
    the session
  - Return an error if a client tries to create a duplicate
    device
  - Return an error when trying to register a duplicate profile
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Sep  9 2011 vuntz@opensuse.org
- Add baselibs.conf.
* Fri Sep  2 2011 vuntz@opensuse.org
- Update to version 0.1.12:
  + New Features:
  - Add a configure argument --enable-volume-search
  - Add a configure argument of --enable-fd-fallback
  - Add cd_client_import_profile() to be able to easily import a
    GFile
  - Allow the daemon to run with a different user
  + Bugfixes:
  - Add daemon user to acl of sensor devices
  - Add lcms2 to Requires.private
  - Check if a file is really an ICC profile before importing it
  - Detect libusb_strerror in configure rather than relying on
    the version
  - Do not fail make check if there is no available local colord
    process to use
  - Ensure the profiles are sorted by their timestamp during
    login
  - Ensure the volume-sourced profiles are not marked as
    systemwide profiles
  - Exit with an error when trying to connect to a device that
    does not exist
  - Remove duplicate call to complete in libcolord
  - Try harder to use the ICC profile checksum
- Changes from version 0.1.11:
  + New Features:
  - Enable GObject introspection generation on libcolord
  - Generate a Vala API binding from the GObject Introspection
    GIR
  - Move the project home to freedesktop.org
  - Ship generated man pages in tarballs
  + Bugfixes:
  - Add all of the required GObject Introspection annotations
    required
  - Allow FindDeviceByProperty() to match on model, vendor and
    serial number
  - Don't crash the example program if there is no default
    profile assigned
  - Fix the bugzilla and mailing list links on the webpage
    (fdo#39129).
  - Fix the licence headers in colord.h and cd-color.h
  - Fix up some translatable strings
  - Honor ACLOCAL_FLAGS when running autoreconf
  - Use the const formatter when unwrapping GVariants to reduce
    memory allocation
  + Updated translations.
- Add gobject-introspection-devel and vala BuildRequires to build
  introspection data and vala bindings.
- Manually install pre-built man pages, since the build system
  cannot install them if docbook2man is not there (and we don't
  want to add a BuildRequires on it since it's big).
* Mon Jul 11 2011 vuntz@opensuse.org
- Remove docbook-utils BuildRequires as an attempt to remove a
  build cycle in Factory.
- This means we lose man pages for now, but upstream will ship them
  pre-generated in tarballs in the future.
* Wed Jul  6 2011 vuntz@opensuse.org
- Update to version 0.1.10:
  + New Features:
  - Add a find-profile-by-filename command to the colormgr client
    tool
  - Add the object scope to the DBus interface as a property
  - Write a document detailing the colord security attack surface
  + Bugfixes:
  - Actually store the device ID in the mapping database
  - Fix include statements to search from current libcolord
    folder
  - Fix mbstowcs usage
  - Fix the build for old versions of lcms2
  - Fix up the location of the libcolord header files
  - Remove the DBus annotations in the introspection
* Mon Jul  4 2011 vuntz@opensuse.org
- Drop rpmlintrc as bnc#698250 got fixed and
  suse-dbus-unauthorized-service/polkit-unauthorized-privilege
  warnings are now gone.
* Thu Jun 16 2011 vuntz@opensuse.org
- Update to version 0.1.9:
  + New Features:
  - Add a 'Format' property to the device interface
  - Add a new method Client:FindDeviceByProperty for when only a
    property is known
  - Add methods to get the connected state of each object
  - Define the DATA_source profile metadata item
  - Define three metadata keys for the framework creator to set
  - Define two keys to allow the profile to contain the mapping
    parameters
  + Bugfixes:
  - Allow GUDEV to be disabled at compile time
  - Autodetect SANE in configure
  - Fix 3 small memory leaks
  - Fix a bug that caused a critical warning in client code
  - Only warn if we fail to get the PolicyKit authority
  - Save any additional disk device metadata in the property
    database
  - Use upstream gettext instead the glib one
  - Write the new metadata entries in the utility programs
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Thu Jun 16 2011 vuntz@opensuse.org
- Add docbook-utils BuildRequires to build man pages.
- Add colord Recommends to libcolord1 as the library is not too
  useful without the daemon.
- Add shared-color-profiles Requires to colord, as we want to have
  profiles.
* Mon Jun  6 2011 dimstar@opensuse.org
- Initial package, version 0.1.8.
